[−][src]Module pyc_shell::shell
Shell
shell is the module which handles the shell execution and the communication with the child shell process. It also takes care of providing the prompt
Modules
| history | History |
| proc | Proc |
| prompt | Prompt |
| unixsignal | UnixSignal |
Structs
| Shell | Shell |